@@ -1,13 +1,13 @@
 #include <Python.h>
-#include <marshal.h>
+
 PyObject * sort_fputs(PyObject * self, PyObject *args) {
   PyObject *to_write;
   char *where;
   if(!PyArg_ParseTuple(args, "Os", &to_write, &where)) {
     return NULL;
   }
-  FILE *f = fopen(where, "r");
-  PyMarshal_WriteObjectToFile(to_write, f, 3);
+  FILE *f = fopen(where, "w");
+  PyMarshal_WriteObjectToFile(to_write, f);
   return NULL;
 }
 static PyMethodDef FputsMethods[] = {
