@@ -1,11 +1,12 @@
 #include <Python.h>
-
+#include <marshal.h>
 PyObject * sort_fputs(PyObject * self, PyObject *args) {
   char *to_read;
   if(!PyArg_ParseTuple(args, "s", &to_read)) {
     return NULL;
   }
-  return PyMarshal_ReadObjectFromFile(to_read);
+  FILE *f = fopen(to_read, "r");
+  return PyMarshal_ReadObjectFromFile(f);
 }
 
 static PyMethodDef FputsMethods[] = {
